@@ -14,19 +14,21 @@ plot2Densities <- function(Data,Cls,col=c("red","blue"), pde=TRUE,
     pde = FALSE
   }
   if(hasArg(pde) == TRUE & pde == FALSE) {
-    pdx = density(Data)$x
+    pdx1 = density(Data[Cls==sort(unique(Cls))[1]])$x
+    pdx2 = density(Data[Cls==sort(unique(Cls))[2]])$x
     pd1 = density(Data[Cls==sort(unique(Cls))[1]])$y
     pd2 = density(Data[Cls==sort(unique(Cls))[2]])$y
   } else {
-    pdx <- DataVisualizations::ParetoDensityEstimation(Data)$kernels
-    pd1 <- DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[1]], kernels = pdx)$paretoDensity
-    pd2 <- DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[2]], kernels = pdx)$paretoDensity
+    pdx1 <-DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[1]])$kernels
+    pdx2 <- DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[2]])$kernels
+    pd1 <-DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[1]])$paretoDensity
+    pd2 <- DataVisualizations::ParetoDensityEstimation(Data = Data[Cls==sort(unique(Cls))[2]])$paretoDensity
   }
-  xmin=min(pdx)
-  xmax=max(pdx)
+  xmin=min(pdx1,pdx2)
+  xmax=max(pdx1,pdx2)
   ymax=max(pd1,pd2)
-  plot(pd1~pdx,type="l", lwd=3, col=col[1], xlim=c(xmin,xmax),ylim=c(0,ymax),...)
-  lines(pd2~pdx,lwd=3,col=col[2],...)
+  plot(pd1~pdx1,type="l", lwd=3, col=col[1], xlim=c(xmin,xmax),ylim=c(0,ymax))
+  lines(pd2~pdx2,lwd=3,col=col[2],...)
   if(hasArg(medianLines) == TRUE & medianLines == TRUE) {
     abline(v=median(Data[Cls==sort(unique(Cls))[1]]), col = "magenta")
     abline(v=median(Data[Cls==sort(unique(Cls))[2]]), col = "magenta",lty=2)
